/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.mail.service.impl.guests;

import java.util.Objects;
import org.json.JSONObject;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.ldap.User;
import com.openexchange.guard.internal.authentication.AuthenticationTokenUtils;
import com.openexchange.guard.internal.authentication.GuardAuthenticationToken;
import com.openexchange.guard.osgi.Services;
import com.openexchange.session.Session;
import com.openexchange.user.UserService;

/**
 * {@link GuardGuestAuthHelper} contains some helper methods for creating a guest authentication object for accessing OX Guard
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v7.10.0
 */
class GuardGuestAuthHelper {

    /**
     * Internal Method to convert a {@link GuardAuthenticationToken} to a JSONObject
     *
     * @param authToken The Auth Token to convert.
     * @return The JSON representation of the given authToken
     */
    static JSONObject toAuthJSON(GuardAuthenticationToken authToken) {
        if (authToken == null) {
            return null;
        }
        return AuthenticationTokenUtils.toJsonObject(authToken);
    }

    /**
     * Internal helper method to convert a User object in a password less authentication object
     *
     * @param user The user to get a password-less authentication object for
     * @return The passwordless auth object
     */
    static JSONObject toAuthJSON(User user) {
        user = Objects.requireNonNull(user, "user must not be null");
        final JSONObject jsonUser = new JSONObject();
        jsonUser.putSafe("email", user.getMail());
        final JSONObject json = new JSONObject();
        json.putSafe("user", jsonUser);
        return json;
    }

    /**
     * Internal helper method get an authentication object from the given objects
     * @param authToken
     * @param session
     * @return An authentication object suitable for OX Guard guest access
     * @throws OXException
     */
     static JSONObject toAuthJSON(GuardAuthenticationToken authToken, Session session) throws OXException {
         JSONObject auth = toAuthJSON(authToken);
         if(auth != null) {
             return auth;
         }
        UserService userService = Services.getService(UserService.class);
        User user = userService.getUser(session.getUserId(), session.getContextId());
        return toAuthJSON(user);
     }
}
